@@ -85,6 +85,21 @@ class TestAhbExpressionParser:
                     ],
                 ),
             ),
+            pytest.param(
+                "Kann([1]∨[5])∧[904]",
+                Tree(
+                    "ahb_expression",
+                    [
+                        Tree(
+                            "single_requirement_indicator_expression",
+                            [
+                                Token("MODAL_MARK", "Kann"),
+                                Token("CONDITION_EXPRESSION", "([1]∨[5])∧[904]"),
+                            ],
+                        ),
+                    ],
+                ),
+            ),
             pytest.param(
                 "X[1]O[5]",
                 Tree(
@@ -145,6 +160,21 @@ class TestAhbExpressionParser:
                     ],
                 ),
             ),
+            pytest.param(
+                "Kann([1]∧[5])∧[905]",
+                Tree(
+                    "ahb_expression",
+                    [
+                        Tree(
+                            "single_requirement_indicator_expression",
+                            [
+                                Token("MODAL_MARK", "Kann"),
+                                Token("CONDITION_EXPRESSION", "([1]∧[5])∧[905]"),
+                            ],
+                        ),
+                    ],
+                ),
+            ),
             pytest.param(
                 "Muss[3]U[4]Soll[5]    Kann[502]",
                 Tree(
@@ -221,6 +251,6 @@ class TestAhbExpressionParser:
 
         assert """Please make sure that the ahb_expression starts with a requirement indicator \
 (i.e Muss, Soll, Kann, X, O, U) and the condition expressions consist of only \
-the following characters: [ ] ( ) U O X and digits.""" in str(
+the following characters: [ ] ( ) U ∧ O ∨ X ⊻ and digits.""" in str(
             excinfo.value
         )
